@@ -526,6 +526,9 @@
           throw new TypeError(`HTTP status code ${res.status}`);
         }
 
+        // Pass the resolved URL to v8.
+        core.opSync("op_wasm_streaming_set_url", rid, res.url);
+
         // 2.6.
         // Rather than consuming the body as an ArrayBuffer, this passes each
         // chunk to the feed as soon as it's available.
